package XML::Grammar::Fiction::Base;

use strict;
use warnings;

use Moose;

=head1 NAME

XML::Grammar::Fiction::Base - base class for XML::Grammar::Fiction
classes.

=head1 VERSION

Version 0.1.0

=cut

our $VERSION = '0.1.0';

=head1 METHODS

=head2 $package->new({%args});

Constructs a new package

=cut

1;

